##NOTE
# Please read packaging.README before updating #########################

%define major   0.3
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

# We need to force optimizations to specific values since the build system and
# host system will likely be different.
%ifarch %ix86 x86_64
    %global _cpuopt "-DAVX=TRUE"
%endif
%ifarch %arm
    %global _cpuopt "-DNEON=TRUE"
%endif
%ifarch aarch64
    # NEON instructions are native in arm64.
    %global _cpuopt ""
%endif

Name:           lpcnetfreedv
Version:        0.3
Release:        %mkrel 1
Summary:        LPCNet for FreeDV
Group:          Communications/Radio
License:        BSD
URL:            https://github.com/drowe67/LPCNet
Source0:        https://github.com/drowe67/LPCNet/archive/refs/tags/v%{version}/%{name}-%{version}.tar.gz
Source1:        http://rowetel.com/downloads/deep/lpcnet_191005_v1.0.tgz
Source2:        packaging.README

BuildRequires:  cmake
BuildRequires:  pkgconfig(codec2) >= 1.0.3

%description
Experimental version of LPCNet that has been used to develop FreeDV 2020 - a HF
radio Digial Voice mode for over the air experimentation with Neural Net speech
coding. Possibly the first use of Neural Net speech coding in real world
operation.

%package -n %{libname}
Summary:        LPCNet for FreeDV shared libraries
Group:          System/Libraries
Obsoletes:      lpcnetfreedv < 0.2-5

%description -n %{libname}
%{summary}.

%package -n %{devname}
Summary:        LPCNet for FreeDV development files and tools
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       lpcnetfreedv-devel = %{version}-%{release}
Obsoletes:      lpcnetfreedv-devel < 0.2-5

%description -n %{devname}
%{summary}.

%prep
%autosetup -p1 -n LPCNet-%{version}

%build
# Add model data archive to the build directory so CMake finds it.
mkdir -p %{_vpath_builddir}
cp -a %{SOURCE1} %{_vpath_builddir}/

%cmake -DDISABLE_CPU_OPTIMIZATION=TRUE %{_cpuopt}
%cmake_build

%install
%cmake_install

%files -n %{libname}
%license COPYING
%doc README.md
%{_libdir}/lib%{name}.so.%{major}

%files -n %{devname}
%{_bindir}/*
%{_includedir}/lpcnet/
%{_libdir}/cmake/lpcnetfreedv/
%{_libdir}/lib%{name}.so


%changelog
* Sat Jul 23 2022 barjac <barjac> 0.3-1.mga9
+ Revision: 1870549
- new version 0.3

* Thu Jan 20 2022 barjac <barjac> 0.2-7.20211003_0dc5935.mga9
+ Revision: 1769278
- rebuild for codec2-1.0.3

* Mon Oct 04 2021 barjac <barjac> 0.2-6.20211003_0dc5935.mga9
+ Revision: 1749449
- Use upstream git master
- rebuild with vanilla codec2 to avoid circular dep
- remove patches that appear fixed upstream

* Sat Oct 02 2021 wally <wally> 0.2-6.mga9
+ Revision: 1747384
- build library as a shared library with proper soname
- fix lib and devel pkg names

* Tue Sep 28 2021 barjac <barjac> 0.2-5.mga9
+ Revision: 1746813
- rebuild for codec2-1.0.1

* Tue Sep 21 2021 barjac <barjac> 0.2-4.mga9
+ Revision: 1746116
- Rebuild for gnuradio-3.9.3.0-rc1

* Mon Aug 31 2020 barjac <barjac> 0.2-3.mga8
+ Revision: 1620548
- fix %%_cpuopt definition for x86
- try globals at top of spec
- adjust spec for Mageia
- import package from Fedora


* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-4
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed May 13 2020 Richard Shaw <hobbes1069@gmail.com> - 0.2-2
- Update per reviewer comments.
- Renamed package to lpcnetfreedv (same as library), repo will be renamed in
  the near future.
- Made library private as it is essentially a plugin for freedv.

* Mon Apr 20 2020 Richard Shaw <hobbes1069@gmail.com> - 0.2-1
- Initial packaging.
